# Changelog

<!--next-version-placeholder-->

## v1.3.0 (2020-10-19)
### Feature
* Add the aliquot protocol ([`b79b206`](https://github.com/kalekundert/stepwise_mol_bio/commit/b79b2066eee246beeb4fd4868623b74445465ee1))
* Add flags to skip either step of inverse PCR ([`07bdf44`](https://github.com/kalekundert/stepwise_mol_bio/commit/07bdf44a6023e2683eb4786be8bfec36e19b69fe))
* Add the -n flag for restriction digests ([`e80f0f8`](https://github.com/kalekundert/stepwise_mol_bio/commit/e80f0f80f44994b95cc0d558b35a26b51c6186e8))
* Add flag for gradient PCR ([`f7e9454`](https://github.com/kalekundert/stepwise_mol_bio/commit/f7e945469b38a355bb01253f38c8c51d2bd64ff8))
* Make imaging step optional (for staining protocols) ([`2cf793f`](https://github.com/kalekundert/stepwise_mol_bio/commit/2cf793fdff6359fee45aead23a5458b77683a517))

### Fix
* Make the time parameters integers ([`165dca9`](https://github.com/kalekundert/stepwise_mol_bio/commit/165dca9cabf46dfb3d0ed14eec3ee53e6cda6622))
* Give salt concentrations in molarity instead of percent ([`15a4693`](https://github.com/kalekundert/stepwise_mol_bio/commit/15a46938cf01d6f8851bbc72bbd69f6474a5e1a9))
* Correct primer volumes for scaled PCR reactions ([`3bc8d42`](https://github.com/kalekundert/stepwise_mol_bio/commit/3bc8d422ea8bfb9a5cfcbef79d170174f90b34be))
